@@ -14,13 +14,14 @@ import pydecode.lp as lp
 import pulp
 import sys
 
+
 class DynamicProgrammingModel(StructuredModel):
     """
     An implementation of a structured model for dynamic programming.
 
     Minimally implement
     :py:method:`DynamicProgrammingModel.dynamic_program` and
-    :py:method:`DynamicProgrammingModel.factored_psi` to use.
+    :py:method:`DynamicProgrammingModel.factored_joint_feature` to use.
 
     """
     def __init__(self, constrained=False, use_gurobi=True,
@@ -31,7 +32,6 @@ class DynamicProgrammingModel(StructuredModel):
         self._use_relaxed = use_relaxed
         self._debug = False
 
-
     def dynamic_program(self, x, chart):
         r"""
         Construct the dynamic program for this input example.
@@ -52,7 +52,7 @@ class DynamicProgrammingModel(StructuredModel):
         return None
         #raise NotImplementedError()
 
-    def factored_psi(self, x, index, data):
+    def factored_joint_feature(self, x, index, data):
         """
         Compute the features for a given index.
 
@@ -73,14 +73,14 @@ class DynamicProgrammingModel(StructuredModel):
         """
         raise NotImplementedError()
 
-    def psi(self, x, y, fractions=None):
+    def joint_feature(self, x, y, fractions=None):
         if not fractions:
             fractions = [1] * len(y)
         assert(len(fractions) == len(y))
         features = {}
         data = self.initialize_features(x)
         for index, frac in zip(y, fractions):
-            f = self.factored_psi(x, index, data)
+            f = self.factored_joint_feature(x, index, data)
             for k, v in f.iteritems():
                 features.setdefault(k, 0)
                 features[k] += v * frac
@@ -93,7 +93,7 @@ class DynamicProgrammingModel(StructuredModel):
         sets = []
         for x, y in zip(X, Y):
             data = self.initialize_features(x)
-            sets += [self.factored_psi(x, index, data)
+            sets += [self.factored_joint_feature(x, index, data)
                      for index in y]
         for s in sets:
             for k, v in s.iteritems():
@@ -101,56 +101,56 @@ class DynamicProgrammingModel(StructuredModel):
                 features[k] += v
 
         t = self._vec.fit_transform(features)
-        self.size_psi = t.size
+        self.size_joint_feature = t.size
 
     def inference(self, x, w, relaxed=False):
         relaxed = relaxed or self._use_relaxed
-        if self._debug: a = time.time()
+        if self._debug:
+            a = time.time()
         hypergraph = self._build_hypergraph(x)
-        if self._debug: print >>sys.stderr, "BUILD HYPERGRAPH:", time.time() -a 
+        if self._debug:
+            print >>sys.stderr, "BUILD HYPERGRAPH:", time.time() - a
 
-        if self._debug: a = time.time()
+        if self._debug:
+            a = time.time()
         potentials = self._build_potentials(hypergraph, x, w)
-        if self._debug: print >>sys.stderr, "BUILD POTENTIALS:", time.time() - a
+        if self._debug:
+            print >>sys.stderr, "BUILD POTENTIALS:", time.time() - a
         if not self._constrained:
-            if self._debug: a = time.time()
+            if self._debug:
+                a = time.time()
             path = ph.best_path(hypergraph, potentials)
-            if self._debug: print >>sys.stderr, "BEST PATH:", time.time() - a
-
+            if self._debug:
+                print >>sys.stderr, "BEST PATH:", time.time() - a
         else:
-            if self._debug: a = time.time()
+            if self._debug:
+                a = time.time()
             constraints = self.constraints(x, hypergraph)
-            hyperlp = lp.HypergraphLP.make_lp(hypergraph, potentials, integral=not relaxed)
+            hyperlp = lp.HypergraphLP.make_lp(hypergraph,
+                                              potentials,
+                                              integral=not relaxed)
             hyperlp.add_constraints(constraints)
-            if self._debug: print >>sys.stderr, "BUILD LP:", time.time() - a
+            if self._debug:
+                print >>sys.stderr, "BUILD LP:", time.time() - a
 
-            if self._debug: a = time.time()
+            if self._debug:
+                a = time.time()
             if self._use_gurobi:
                 hyperlp.solve(pulp.solvers.GUROBI(mip=1 if not relaxed else 0))
             else:
-                hyperlp.solve(pulp.solvers.GLPK(mip=1 if not relaxed else 0 ))
-            if self._debug: print >>sys.stderr, "SOLVE LP:", time.time() - a
+                hyperlp.solve(pulp.solvers.GLPK(mip=1 if not relaxed else 0))
+            if self._debug:
+                print >>sys.stderr, "SOLVE LP:", time.time() - a
 
             if relaxed:
                 path = hyperlp.decode_fractional()
             else:
                 path = hyperlp.path
-        if self._debug: print 
+        if self._debug:
+            print
         y = set([edge.label for edge in path])
         return y
 
-
-
-            #print repr(hypergraph.label(edge))
-        # print len(path.edges)
-        #print "DONE"
-
-        # a = time.time()
-        # print time.time() - a
-        # b = time.time()
-        # print time.time() - b
-        #print "SCORE IS:", potentials.dot(path)
-
     def loss(self, yhat, y):
         difference = 0
         # print "GOLD", y
@@ -174,9 +174,10 @@ class DynamicProgrammingModel(StructuredModel):
 
     def _build_potentials(self, hypergraph, x, w):
         data = self.initialize_features(x)
-        features = [self.factored_psi(x, hypergraph.label(edge), data) for edge in hypergraph.edges]
+        features = [self.factored_joint_feature(x, edge.label, data)
+                    for edge in hypergraph.edges]
         f = self._vec.transform(features)
-        scores =  f * w.T
+        scores = f * w.T
         #print "Weights:", self._vec.inverse_transform(w)
         #print
         return ph.Potentials(hypergraph).from_vector(scores)
@@ -194,7 +195,7 @@ class DynamicProgrammingModel(StructuredModel):
 
 
     # def _features(self, x, index, data):
-    #     d = self.factored_psi(x, index, data)
+    #     d = self.factored_joint_feature(x, index, data)
     #     # This is slow.
     #     return self._vec.transform(d) # {s: 1 for s in d})
 
